# redisx-py
[![MIT licensed](https://img.shields.io/badge/license-MIT-blue.svg)](./LICENSE)


## Install
* python version >=3.10
* redis-py version == 5.0.0

Install from pip:
```shell
python3 -m venv .venv
source .venv/bin/activate
pip3 install redisx
```

Install from source:

```shell
git clone https://github.com/weedge/redisx-py.git
cd redisx-py
python3 setup.py install
```
## run examples
```shell
python3 examples/ann_usearch.py
```

# Reference
0. https://devguide.python.org/versions/
1. https://github.com/redis/redis-py
2. https://github.com/alibaba/tair-py
